@@ -29,8 +29,15 @@ cluster_schema = {
     "required": ["ids"],
 }
 
+global_schema = {
+    "type": "object"
+}
+
 def validate_feature(data):
     validate(data, feature_schema)
 
 def validate_cluster(data):
     validate(data, cluster_schema)
+
+def validate_global(data):
+    validate(data, global_schema)
\ No newline at end of file
