@@ -13,6 +13,13 @@ def feature_data(self, key):
         u'clusters': [u'general/clusters/cluster-google-merchant'],
         u'enable': True}
 
+def global_list(self, path):
+    return [u'general/globals/test-global']
+
+def global_data(self, key):
+    data = {'general/globals/test-global': {'some': 'random', 'test': 'values'}}
+    return data[key]
+
 def invalid_feature_data(self, key):
     return {
         u'clusters': [u'general/clusters/cluster-google-merchant'],
@@ -21,6 +28,9 @@ def invalid_feature_data(self, key):
 def invalid_cluster_data(self, key):
     return {u'ids': ["123", 456]}
 
+def invalid_global_data(self, key):
+    return 'some random test values'
+
 def cache_init_data(self, key):
     if 'cluster' in key :
         return cluster_data(self, key)
