@@ -99,4 +99,23 @@ def test_cluster_feature_cluster_update_cache():
     RemoteConfig._get_value = mock.cache_update_cluster_data
     rc._load_clusters()
     rc._load_features()
-    assert rc.get_feature('google-merchant', 123) == False
\ No newline at end of file
+    assert rc.get_feature('google-merchant', 123) == False
+
+def test_missing_global():
+    RemoteConfig().globals = {}
+    assert RemoteConfig().get_global('test-global') is None
+
+def test_valid_global():
+    RemoteConfig().globals = {}
+    RemoteConfig._list_folders = mock.global_list
+    RemoteConfig._get_value = mock.global_data
+
+    RemoteConfig()._load_globals()
+    assert RemoteConfig().get_global('test-global') == {'some': 'random', 'test': 'values'}
+
+def test_invalid_global():
+    RemoteConfig().globals = {}
+    RemoteConfig._list_folders = mock.global_list
+    RemoteConfig._get_value = mock.invalid_global_data
+    with pytest.raises(ValidationError):
+        RemoteConfig()._load_globals()
\ No newline at end of file
